%global momorel 9
%global tarball_ver 1_34_1

Name: boost
Summary: The Boost C++ Libraries
Version: 1.34.1
Release: %{momorel}m%{?dist}
License: "Boost Software License"
URL: http://www.boost.org/
Group: System Environment/Libraries
Source0: http://dl.sourceforge.net/sourceforge/boost/boost_%{tarball_ver}.tar.bz2 
NoSource: 0
Obsoletes: boost-doc
Obsoletes: boost-python
Provides: boost-python

%{?include_specopt}
#  If you'd like to change these configurations, please copy them to
# ~/rpm/specopt/boost.specopt and edit it.
%{?!do_test: %global do_test 0}	   

Patch0: boost-configure.patch
Patch1: boost-gcc-soname.patch
Patch2: boost-use-rpm-optflags.patch
Patch3: boost-run-tests.patch
Patch4: boost-regex.patch
Patch5: boost-gcc43.patch

# http://svn.boost.org/trac/boost/ticket/1260
Patch10: boost-1.34.1-multi-threaded-bug.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python 
BuildRequires: boost-jam >= 3.1.14-2m
BuildRequires: gcc-c++ >= 3.4.1-1m
BuildRequires: libstdc++-devel
BuildRequires: zlib-devel
BuildRequires: bzip2-devel
BuildRequires: python-devel
BuildRequires: libicu-devel >= 4.0

%description
Boost provides free peer-reviewed portable C++ source libraries.  The
emphasis is on libraries which work well with the C++ Standard
Library.  One goal is to establish "existing practice" and provide
reference implementations so that the Boost libraries are suitable for
eventual standardization. (Some of the libraries have already been
proposed for inclusion in the C++ Standards Committee's upcoming C++
Standard Library Technical Report.)

%package devel
Summary: The Boost C++ headers and shared development libraries
Group: Development/Libraries
Requires: boost = %{version}-%{release}
Obsoletes: boost-python-devel
Provides: boost-python-devel = %{version}-%{release}

%description devel
Headers and shared object symlinks for the Boost C++ libraries.

%package devel-static
Summary: The Boost C++ static development libraries
Group: Development/Libraries
Requires: boost = %{version}-%{release}
Provides: boost-python-devel = %{version}-%{release}

%description devel-static
Static libraries for the Boost C++ libraries.

%package doc
Summary: The Boost C++ html docs
Requires: boost = %{version}-%{release}
Group: Documentation
Provides: boost-python-docs = %{version}-%{release}
 
%description doc
HTML documentation files for Boost C++ libraries.

%prep
rm -rf %{buildroot}

%setup -q -n %{name}_%{tarball_ver}
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0 -b .test~
%patch4 -p0 -b .regex~
%patch5 -p1 -b .gcc43~

%patch10 -p1

%build

##build bjam
#(cd tools/jam/src && ./build.sh)
#BJAM=`find tools/jam/src/ -name bjam -a -type f`

BJAM=/usr/bin/bjam

BUILD_FLAGS="--with-bjam=$BJAM --with-toolset=gcc"
PYTHON_VERSION=$(python -c 'import sys; print sys.version[:3]')
PYTHON_FLAGS="--with-python-root=/usr --with-python-version=$PYTHON_VERSION"
REGEX_FLAGS="--with-icu"
./configure $BUILD_FLAGS $PYTHON_FLAGS $REGEX_FLAGS 
%make all

# we need this hack because boost does not guarantee any ABI
for i in `find stage -type f -name \*.so`; do
  NAME=$i
  SONAME=$i.3
  VNAME=$i.%{version}
  base=`basename $i`
  NAMEbase=$base
  SONAMEbase=$base.3
  VNAMEbase=$base.%{version}
  mv $i $VNAME
  ln -s $VNAMEbase $SONAME
  ln -s $VNAMEbase $NAME
done

%if %{do_test}
case "`gcc -dumpversion`" in
4.2.*)
  # see http://svn.boost.org/trac/boost/ticket/977
  export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
  ;;
esac
# the SONAME hack breaks some regression tests now.
sh ./tools/regression/run_tests.sh
%endif

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_docdir}/boost-%{version}

# install libs in stage/
for i in `find stage -type f -name \*.a`; do
  install -p -m 0644 $i %{buildroot}%{_libdir}/
done
for i in `find stage -type f -name \*.so.%{version}`; do
  install -p -m 0755 $i %{buildroot}%{_libdir}/
done
for i in `find stage -type l -name \*.so\*`; do
  cp -a $i %{buildroot}%{_libdir}/
done

# install include files
for i in `find boost -type d`; do
  mkdir -p %{buildroot}%{_includedir}/$i
done
for i in `find boost -type f`; do
  install -p -m 0644 $i %{buildroot}%{_includedir}/$i
done

#install doc files
cd doc/html
for i in `find . -type d`; do
   mkdir -p %{buildroot}%{_docdir}/boost-%{version}/$i
done
for i in `find . -type f`; do
  install -p -m 644 $i %{buildroot}%{_docdir}/boost-%{version}/$i
done
cd ../..
 
# remove scripts used to generate include files 
find %{buildroot}%{_includedir}/ \( -name '*.pl' -o -name '*.sh' \) -exec rm {} \;

%clean
rm -rf %{buildroot} 

%post 
/sbin/ldconfig

%postun 
/sbin/ldconfig

%files
%defattr(-, root, root, -)
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.3

%files devel
%defattr(-, root, root, -)
%{_includedir}/boost
%{_libdir}/*.so

%files devel-static
%defattr(-, root, root, -)
%{_libdir}/*.a

%files doc
%defattr(-, root, root, -)
%doc %{_docdir}/boost-%{version}

%changelog
* Sun Jul  6 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.34.1-9m)
- rebuild against icu-4.0

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.34.1-8m)
- rebuild against gcc43

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.34.1-8m)
- rebuild against gcc43

* Fri Feb 22 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-7m)
- update boost-gcc43.patch

* Sun Feb 17 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.34.1-6m)
- rebuild against icu-3.8.1

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.34.1-5m)
- %%NoSource -> NoSource

* Thu Feb  7 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-4m)
- import two patches from fc-devel

* Sun Jan  6 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.34.1-3m)
- fixed criticul bug fix.
-- http://svn.boost.org/trac/boost/ticket/1260

* Mon Oct 29 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-2m)
- fixed regression tests failure with gcc-4.2
- build and regression tests now use installed /usr/bin/bjam

* Mon Aug 13 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-1m)
- update to 1.34.1
- merge a lot of changes between fc-devel's boost-1_33_1-6 and boost-1_34_1-3_fc8
-- update SONAME to 3 due to ABI changes
-- add devel-static package for .a libs
-- add regression tests

* Sun Jan  7 2007 Dai OKUYAMA <dai@ouchi.nahi.to>
- (1.33.1-3m)
- build fix with python 2.5

* Thu Oct 12 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.33.1-2m)
- sync FC
-  revised Patch1: boost-gcc-tools.patch
-  add Patch2 boost-thread.patch
-  add Patch3 boost-config-compiler-gcc.patch
-  add Patch4 boost-runtests.patch

* Tue Apr 18 2006 Masayuki SANO
- (1.33.1-1m)
- update to 1.33.1

* Wed Mar  9 2005 Toru Hoshina <t@momonga-linux.org>
- (1.32.0-1m)
- ver up.

* Sun Aug 22 2004 Hiroyuki Koga <kuma@momonga-linux.org>
- (1.31.0-1m)
- update to 1.31.0 (rebuild against gcc-c++-3.4.1)

* Fri May 14 2004 Masahiro Takahata <takahata@momonga-linux.org>
- (1.30.2-4m)
- change URI

* Sun Dec  7 2003 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.30.2-3m)
- adapt the License: preamble for the Momonga Linux license
  expression unification policy (draft)

* Wed Oct 22 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.30.2-2m)
- kill %%define version
- kill %%define release

* Mon Oct 20 2003 Hideo TASHIRO <tashiron@jasmiso.org>
- (1.30.2-1m)
- update to 1.30.2
- change License from "Freeware" to "Distributable"

* Tue Jun 10 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (1.30.0-1m)
- initial version for momonga (imported from rawhide)

* Tue May  6 2003 Tim Powers <timp@redhat.com> 1.30.0-3
- add deffattr's so we don't have unknown users owning files
